"""Unicode Properties from Unicode version 16.0.0 (autogen)."""
from .age import *  # noqa
from .alias import *  # noqa
from .bidiclass import *  # noqa
from .binary import *  # noqa
from .block import *  # noqa
from .bidipairedbrackettype import *  # noqa
from .canonicalcombiningclass import *  # noqa
from .decompositiontype import *  # noqa
from .eastasianwidth import *  # noqa
from .generalcategory import *  # noqa
from .graphemeclusterbreak import *  # noqa
from .hangulsyllabletype import *  # noqa
from .indicpositionalcategory import *  # noqa
from .indicsyllabiccategory import *  # noqa
from .joininggroup import *  # noqa
from .joiningtype import *  # noqa
from .linebreak import *  # noqa
from .numerictype import *  # noqa
from .numericvalue import *  # noqa
from .quickcheck import *  # noqa
from .sentencebreak import *  # noqa
from .script import *  # noqa
from .scriptextensions import *  # noqa
from .verticalorientation import *  # noqa
from .wordbreak import *  # noqa
